@@ -8,13 +8,6 @@ import numpy as np
 import pyarrow as pa
 from pydantic import BaseModel, Extra
 
-
-class MEnum(Enum):
-    @classmethod
-    def list(cls) -> list:
-        return [e.value for e in cls]
-
-
 Field = namedtuple("Field", ["name", "type_"])
 
 
@@ -37,7 +30,7 @@ def get_arrow_type(t: type) -> pa.DataType:
     if t in TYPE_TO_PA_TYPE.keys():
         return TYPE_TO_PA_TYPE[t]
 
-    elif inspect.isclass(t) and issubclass(t, MEnum):
+    elif inspect.isclass(t) and issubclass(t, Enum):
         # return pa_ext.EnumType.from_enum(t)
         return pa.string()
 
@@ -59,6 +52,27 @@ def get_arrow_type(t: type) -> pa.DataType:
 
 
 class Schema(BaseModel, extra=Extra.allow):
+    """Schema for a Motion relation. Read more about relations in Motion [here](/concepts/relation).
+
+    Example:
+
+    ```python
+    class User(Schema):
+        name: str
+        dob: date
+        hometown: str
+    ```
+
+    All schemas also have the following fields, by default:
+    - `identifier` (str): A unique identifier for each record in the relation.
+    - `create_at` (datetime): The time at which the record was created.
+    - `derived_id` (str): The identifier of the record that was derived from, if any.
+    - `session_id` (str): The identifier of the session that created the record.
+
+    Raises:
+        TypeError: If a type is not supported. Supported types are: int, str, float, bool, date, datetime, bytes, list, dict, numpy types, and enums.
+    """
+
     identifier: str
     derived_id: str
     create_at: datetime
@@ -66,10 +80,7 @@ class Schema(BaseModel, extra=Extra.allow):
 
     @classmethod
     def formatPaSchema(cls, relation: str) -> pa.Schema:
-        """Formats a pyarrow schema for the given relation.
-
-        Args:
-            table_name (str): Name of relation.
+        """Formats a pyarrow schema for the given relation. This is used internally by Motion.
 
         Returns:
             pa.Schema: Schema for table based on annotations.
@@ -85,14 +96,13 @@ class Schema(BaseModel, extra=Extra.allow):
             and not f.name == "session_id"
         ]
         pa_fields = [
-            pa.field("identifier", pa.string(), nullable=False),
+            pa.field("identifier", pa.string()),
             pa.field(
                 "create_at",
                 pa.timestamp("us"),
-                nullable=False,
             ),
             pa.field("derived_id", pa.string()),
-            pa.field("session_id", pa.string(), nullable=False),
+            pa.field("session_id", pa.string()),
         ]
 
         for field in user_defined_fields:
